OC.L10N.register(
    "core",
    {
    "Please select a file." : "Valitse tiedosto.",
    "File is too big" : "Tiedosto on liian suuri",
    "Invalid file provided" : "Määritetty virheellinen tiedosto",
    "No image or file provided" : "Kuvaa tai tiedostoa ei määritelty",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "Invalid image" : "Virhellinen kuva",
    "An error occurred. Please contact your admin." : "Tapahtui virhe. Ota yhteys ylläpitoon.",
    "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
    "No crop data provided" : "Puutteellinen tieto",
    "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
    "Crop is not square" : "Leikkaus ei ole neliö",
    "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa koska valtuutus on virheellinen",
    "Couldn't reset password because the token is expired" : "Salasanan palauttaminen ei onnistunut, koska valtuutus on vanhentunut",
    "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Salasanan palautusiviestiä ei voitu lähettää sähköpostitse, koska tälle käyttäjätunnukselle ei ole määritetty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
    "%s password reset" : "%s salasanan palautus",
    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "Error loading tags" : "Virhe tunnisteita ladattaessa",
    "Tag already exists" : "Tunniste on jo olemassa",
    "Error deleting tag(s)" : "Virhe tunnisteita poistaessa",
    "Error tagging" : "Tunnisteiden kirjoitusvirhe",
    "Error untagging" : "Tunisteiden poisto virhe",
    "Error favoriting" : "Suosituksen kirjoitusvirhe",
    "Error unfavoriting" : "Suosituksen poisto virhe",
    "Couldn't send mail to following users: %s " : "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
    "Preparing update" : "Valmistellaan päivitystä",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Korjausvaroitus:",
    "Repair error: " : "Korjausvirhe:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Käytä komentorivipäivitintä, koska automaattinen päivitys on estetty config.php-asetustiedostossa.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
    "Turned on maintenance mode" : "Siirrytty huoltotilaan",
    "Turned off maintenance mode" : "Huoltotila asetettu pois päältä",
    "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
    "Updating database schema" : "Päivitetään tietokannan skeemaa",
    "Updated database" : "Tietokanta ajan tasalla",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
    "Checked database schema update" : "Tarkistettu tietokannan skeemapäivitys",
    "Checking updates of apps" : "Tarkistetaan sovellusten päivityksiä",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
    "Checked database schema update for apps" : "Tarkistettu tietokannan skeemapäivitys sovelluksille",
    "Updated \"%s\" to %s" : "Päivitetty \"%s\" versioon %s",
    "Set log level to debug" : "Aseta lokitustasoksi vianetsintä",
    "Reset log level" : "Nollaa lokitustaso",
    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
    "%s (3rdparty)" : "%s (kolmannen osapuolen)",
    "%s (incompatible)" : "%s (ei yhteensopiva)",
    "Following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
    "Already up to date" : "Kaikki on jo ajan tasalla",
    "Sunday" : "sunnuntai",
    "Monday" : "maanantai",
    "Tuesday" : "tiistai",
    "Wednesday" : "keskiviikko",
    "Thursday" : "torstai",
    "Friday" : "perjantai",
    "Saturday" : "lauantai",
    "Sun." : "Su",
    "Mon." : "Ma",
    "Tue." : "Ti",
    "Wed." : "Ke",
    "Thu." : "To",
    "Fri." : "Pe",
    "Sat." : "La",
    "Su" : "Su",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "Ke",
    "Th" : "To",
    "Fr" : "Pe",
    "Sa" : "La",
    "January" : "tammikuu",
    "February" : "helmikuu",
    "March" : "maaliskuu",
    "April" : "huhtikuu",
    "May" : "toukokuu",
    "June" : "kesäkuu",
    "July" : "heinäkuu",
    "August" : "elokuu",
    "September" : "syyskuu",
    "October" : "lokakuu",
    "November" : "marraskuu",
    "December" : "joulukuu",
    "Jan." : "Tammi",
    "Feb." : "Helmi",
    "Mar." : "Maalis",
    "Apr." : "Huhti",
    "May." : "Touko",
    "Jun." : "Kesä",
    "Jul." : "Heinä",
    "Aug." : "Elo",
    "Sep." : "Syys",
    "Oct." : "Loka",
    "Nov." : "Marras",
    "Dec." : "Joulu",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Eheystarkistus tuotti ongelmia. Lisätietoja…</a>",
    "Settings" : "Asetukset",
    "Problem loading page, reloading in 5 seconds" : "Ongelma sivun lataamisessa, päivitetään 5 sekunnin kuluttua",
    "Saving..." : "Tallennetaan...",
    "Dismiss" : "Hylkää",
    "seconds ago" : "sekuntia sitten",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkki salasanan palauttamista varten on lähetetty sähköpostitse. Jos et saa sähköpostiviestiä kohtuullisessa ajassa, tarkista roskapostikansiot.<br>Jos et saa sähköpostiviestiä, ota yhteys paikalliseen ylläpitäjään.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi on salattu. Jos et ole ottanut käyttöön palautusavainta, tietojasi ei ole mahdollista palauttaa salasanan nollaamisen jälkeen.<br />Jos et ole varma mitä tehdä, ota yhteys ylläpitäjään.<br />Haluatko varmasti jatkaa?",
    "I know what I'm doing" : "Tiedän mitä teen",
    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "No" : "Ei",
    "Yes" : "Kyllä",
    "Choose" : "Valitse",
    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
    "read-only" : "vain luku",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
    "One file conflict" : "Yhden tiedoston ristiriita",
    "New Files" : "Uudet tiedostot",
    "Already existing files" : "Jo olemassa olevat tiedostot",
    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
    "Cancel" : "Peru",
    "Continue" : "Jatka",
    "(all selected)" : "(kaikki valittu)",
    "({count} selected)" : "({count} valittu)",
    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "HTTP-palvelinta ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liittymä vaikuttaa olevan rikki.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Tällä palvelimella ei ole toimivaa internetyhteyttä. Sen seurauksena jotkin ominaisuudet, kuten erillinen tallennustila, ilmoitukset päivityksistä ja kolmansien osapuolten sovellusten asennus eivät toimi. Tiedostojen käyttö etänä tai ilmoitusten lähetys sähköpostitse eivät välttämättä toimi myöskään. Suosittelemme kytkemään palvelimen internetyhteyteen, jos haluat käyttää kaikkia ownCloudin ominaisuuksia.",
    "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datahakemistosi ja tiedostosi ovat luultavasti käytettävissä suoraan internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään http-palvelimen asetukset siten, ettei datahakemisto ole suoraan käytettävissä internetistä, tai siirtämään datahakemiston http-palvelimen juurihakemiston ulkopuolelle.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-otsaketta \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten suosittelemme muuttamaan asetuksen arvoa.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Käytät sivustoa HTTP-yhteydellä. Suosittelemme asettamaan palvelimen vaatimaan HTTPS-yhteyden, kuten <a href=\"{docUrl}\">tietoturvavinkeissä</a> neuvotaan.",
    "Shared" : "Jaettu",
    "Shared with {recipients}" : "Jaettu henkilöiden {recipients} kanssa",
    "Error" : "Virhe",
    "Error while sharing" : "Virhe jaettaessa",
    "Error while unsharing" : "Virhe jakoa peruttaessa",
    "Error setting expiration date" : "Virhe päättymispäivää asettaessa",
    "The public link will expire no later than {days} days after it is created" : "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
    "Set expiration date" : "Aseta päättymispäivä",
    "Expiration" : "Erääntyminen",
    "Expiration date" : "Päättymispäivä",
    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
    "Resharing is not allowed" : "Jakaminen uudelleen ei ole salittu",
    "Share link" : "Jaa linkki",
    "Link" : "Linkki",
    "Password protect" : "Suojaa salasanalla",
    "Password" : "Salasana",
    "Allow editing" : "Salli muokkaus",
    "Email link to person" : "Lähetä linkki sähköpostitse",
    "Send" : "Lähetä",
    "Sending ..." : "Lähetetään...",
    "Email sent" : "Sähköposti lähetetty",
    "Send link via email" : "Lähetä linkki sähköpostitse",
    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
    "Shared with you by {owner}" : "Jaettu kanssasi käyttäjän {owner} toimesta",
    "group" : "ryhmä",
    "remote" : "etä",
    "notify by email" : "ilmoita sähköpostitse",
    "Unshare" : "Peru jakaminen",
    "can share" : "jaa",
    "can edit" : "voi muokata",
    "create" : "luo",
    "change" : "muuta",
    "delete" : "poista",
    "access control" : "Pääsyn hallinta",
    "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
    "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
    "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
    "No users found for {search}" : "Haulla {search} ei löytynyt käyttäjiä",
    "An error occurred. Please try again" : "Tapahtui virhe, yritä uudelleen",
    "{sharee} (group)" : "{sharee} (ryhmä)",
    "{sharee} (at {server})" : "{sharee} (palvelimella {server})",
    "{sharee} (remote)" : "{sharee} (etä)",
    "Share" : "Jaa",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Jaa toisia ownCloud-järjestelmiä käyttävien kesken käyttäen syntaksia käyttäjätunnus@esimerkki.fi/owncloud",
    "Share with users…" : "Jaa käyttäjien kanssa…",
    "Share with users, groups or remote users…" : "Jaa käyttäjien, ryhmien tai etäkäyttäjien kanssa…",
    "Share with users or groups…" : "Jaa käyttäjien tai ryhmien kanssa…",
    "Share with users or remote users…" : "Jaa käyttäjien tai etäkäyttäjien kanssa…",
    "Error removing share" : "Virhe jakoa poistaessa",
    "Warning" : "Varoitus",
    "Error while sending notification" : "Virhe ilmoitusta lähettäessä",
    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
    "restricted" : "rajoitettu",
    "invisible" : "näkymätön",
    "({scope})" : "({scope})",
    "Delete" : "Poista",
    "Rename" : "Nimeä uudelleen",
    "Collaborative tags" : "Yhteistyölliset tunnisteet",
    "The object type is not specified." : "The object type is not specified.",
    "Enter new" : "Kirjoita uusi",
    "Add" : "Lisää",
    "Edit tags" : "Muokkaa tunnisteita",
    "Error loading dialog template: {error}" : "Virhe ladatessa keskustelupohja: {error}",
    "No tags selected for deletion." : "Tunnisteita ei valittu poistettavaksi.",
    "unknown text" : "tuntematon teksti",
    "Hello world!" : "Hei maailma!",
    "sunny" : "aurinkoinen",
    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
    "Hello {name}" : "Hei {name}",
    "new" : "uusi",
    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
    "Updating to {version}" : "Päivitetään versioon {version}",
    "An error occurred." : "Tapahtui virhe.",
    "Please reload the page." : "Päivitä sivu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Päivitys epäonnistui. Ilmoita ongelmasta <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-yhteisölle</a>.",
    "The update was successful. There were warnings." : "Päivitys onnistui, tosin ilmeni varoituksia.",
    "The update was successful. Redirecting you to ownCloud now." : "Päivitys onnistui. Selain ohjautuu nyt ownCloudiisi.",
    "Searching other places" : "Etsitään muista paikoista",
    "No search results in other folders" : "Ei hakutuloksia muissa kansioissa",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hakutulos muussa kansiossa","{count} hakutulosta muissa kansioissa"],
    "Personal" : "Henkilökohtainen",
    "Users" : "Käyttäjät",
    "Apps" : "Sovellukset",
    "Admin" : "Ylläpito",
    "Help" : "Ohje",
    "Access forbidden" : "Pääsy estetty",
    "File not found" : "Tiedostoa ei löytynyt",
    "The specified document has not been found on the server." : "Määritettyä asiakirjaa ei löytynyt palvelimelta.",
    "You can click here to return to %s." : "Napsauta tästä palataksesi %siin.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hei sinä!\n\n%s jakoi kohteen %s kanssasi.\nTutustu siihen: %s\n\n",
    "The share will expire on %s." : "Jakaminen päättyy %s.",
    "Cheers!" : "Kiitos!",
    "Internal Server Error" : "Sisäinen palvelinvirhe",
    "The server encountered an internal error and was unable to complete your request." : "Palvelin kohtasi sisäisen virheen, eikä pystynyt viimeistelmään pyyntöäsi.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Ota yhteys palvelimen ylläpitäjään, jos tämä virhe ilmenee useita kertoja. Lisää yhteydenottoosi alla olevat tekniset tiedot.",
    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
    "Technical details" : "Tekniset tiedot",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "Type: %s" : "Tyyppi: %s",
    "Code: %s" : "Koodi: %s",
    "Message: %s" : "Viesti: %s",
    "File: %s" : "Tiedosto: %s",
    "Line: %s" : "Rivi: %s",
    "Trace" : "Jälki",
    "Security warning" : "Turvallisuusvaroitus",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden saavutettavissa internetistä, koska .htaccess-tiedosto ei toimi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Lisätietoja palvelimen oikeaoppiseen määritykseen on saatavilla <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dokumentaatiossa</a>.",
    "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
    "Username" : "Käyttäjätunnus",
    "Storage & database" : "Tallennus ja tietokanta",
    "Data folder" : "Datakansio",
    "Configure the database" : "Muokkaa tietokantaa",
    "Only %s is available." : "Vain %s on käytettävissä.",
    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
    "For more details check out the documentation." : "Lisätietoja on saatavilla dokumentaatiossa.",
    "Database user" : "Tietokannan käyttäjä",
    "Database password" : "Tietokannan salasana",
    "Database name" : "Tietokannan nimi",
    "Database tablespace" : "Tietokannan taulukkotila",
    "Database host" : "Tietokantapalvelin",
    "Performance warning" : "Suorituskykyvaroitus",
    "SQLite will be used as database." : "SQLitea käytetään tietokantana.",
    "For larger installations we recommend to choose a different database backend." : "Suuria asennuksia varten suositellaan muun tietokannan käyttöä.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Varsinkin työpöytäsovelluksen tiedostosynkronointia käyttäessä SQLiten käyttö ei ole suositeltavaa.",
    "Finish setup" : "Viimeistele asennus",
    "Finishing …" : "Valmistellaan…",
    "Need help?" : "Tarvitsetko apua?",
    "See the documentation" : "Tutustu dokumentaatioon",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei!<br><br>%s jakoi kanssasi kohteen <strong>%s</strong>.<br><a href=\"%s\">Tutustu siihen!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
    "Log out" : "Kirjaudu ulos",
    "Search" : "Etsi",
    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
    "An internal error occurred." : "Tapahtui sisäinen virhe",
    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
    "Log in" : "Kirjaudu sisään",
    "Wrong password. Reset it?" : "Väärä salasana. Haluatko palauttaa salasanan?",
    "Wrong password." : "Väärä salasana.",
    "Stay logged in" : "Pysy sisäänkirjautuneena",
    "Alternative Logins" : "Vaihtoehtoiset kirjautumiset",
    "Use the following link to reset your password: {link}" : "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
    "New password" : "Uusi salasana",
    "New Password" : "Uusi salasana",
    "Reset password" : "Palauta salasana",
    "This ownCloud instance is currently in single user mode." : "Tämä ownCloud-asennus on parhaillaan single user -tilassa.",
    "This means only administrators can use the instance." : "Se tarkoittaa, että vain ylläpitäjät voivat nyt käyttää tätä ownCloudia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
    "Thank you for your patience." : "Kiitos kärsivällisyydestäsi.",
    "Two-step verification" : "Kaksivaiheinen vahvistus",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Tililläsi on käytössä lisäturvatoimia. Tunnistaudu käyttäen kaksivaiheista vahvistusta.",
    "Cancel login" : "Peru kirjautuminen",
    "Please authenticate using the selected factor." : "Tunnistaudu käyttäen valittua vahvistusta.",
    "You are accessing the server from an untrusted domain." : "Olet yhteydessä palvelimeen epäluotettavasta verkko-osoitteesta.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Ota yhteys ylläpitoon. Jos olet tämän asennuksen ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tarjolla tiedostossa config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Riippuen määrityksistä, ylläpitäjänä saatat kyetä käyttämään alla olevaa painiketta luodaksesi luottamussuhteen tähän toimialueeseen.",
    "Add \"%s\" as trusted domain" : "Lisää \"%s\" luotetuksi toimialueeksi",
    "App update required" : "Sovelluksen päivittäminen vaaditaan",
    "%s will be updated to version %s" : "%s päivitetään versioon %s",
    "These apps will be updated:" : "Nämä sovellukset päivitetään:",
    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
    "Start update" : "Käynnistä päivitys",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
    "Detailed logs" : "Yksityiskohtainen loki",
    "Update needed" : "Päivitys vaaditaan",
    "Please use the command line updater because you have a big instance." : "Käytä komentorivipäivitintä, koska käyttämäsi ownCloud on sen verran suuri.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Apua saat <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaatiosta</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä."
},
"nplurals=2; plural=(n != 1);");
